==> zjkj-wzxt-impl-3.0.0-20240806.025714-25-sources.jar: com/ejianc/wzxt/plan/service/impl/MasterPlanChangeHisServiceImpl.java <==
package com.ejianc.wzxt.plan.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.foundation.share.utils.TreeNodeBUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.wzxt.plan.bean.MasterPlanDetailChangeHisEntity;
import com.ejianc.wzxt.plan.enums.ChangeTypeEnum;
import com.ejianc.wzxt.plan.service.IMasterPlanDetailChangeHisService;
import com.ejianc.wzxt.plan.vo.MasterPlanChangeHisVO;
import com.ejianc.wzxt.plan.vo.MasterPlanDetailChangeHisVO;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.wzxt.plan.mapper.MasterPlanChangeHisMapper;
import com.ejianc.wzxt.plan.bean.MasterPlanChangeHisEntity;
import com.ejianc.wzxt.plan.service.IMasterPlanChangeHisService;

import java.util.ArrayList;
import java.util.List;

/**
 * 材料总控计划历史-主表
 * 
 * @author generator
 * 
 */
@Service("masterPlanChangeHisService")
public class MasterPlanChangeHisServiceImpl extends BaseServiceImpl<MasterPlanChangeHisMapper, MasterPlanChangeHisEntity> implements IMasterPlanChangeHisService{


    @Autowired
    private IMasterPlanDetailChangeHisService planDetailChangeHisService;

    @Override
    public MasterPlanChangeHisVO queryDetail(Long id) {
        LambdaQueryWrapper<MasterPlanChangeHisEntity> lambda = Wrappers.<MasterPlanChangeHisEntity>lambdaQuery();
        lambda.eq(MasterPlanChangeHisEntity::getChangePlanId, id);
        MasterPlanChangeHisEntity one = this.getOne(lambda);
        MasterPlanChangeHisVO planChangeHisVO = BeanMapper.map(one, MasterPlanChangeHisVO.class);
        QueryParam queryParam = new QueryParam();
        queryParam.getParams().put("materialMasterPlanId", new Parameter(QueryParam.EQ, one.getId()));
        queryParam.getOrderMap().put("treeIndex", "asc");
        List<MasterPlanDetailChangeHisEntity> detailEntityListDb = planDetailChangeHisService.queryList(queryParam, false);
        List<MasterPlanDetailChangeHisEntity> detailEntityList = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(detailEntityListDb)) {
            detailEntityListDb.forEach(entity ->{
                if(null == entity.getChangeType() || ChangeTypeEnum.中止项.getCode() != entity.getChangeType()){
                    detailEntityList.add(entity);
                }
            });
        }
        if(CollectionUtils.isNotEmpty(detailEntityList)) {
            for(MasterPlanDetailChangeHisEntity cdEntity : detailEntityList){
                cdEntity.setRowState("add");
            }
            List<MasterPlanDetailChangeHisVO> resultMapList = BeanMapper.mapList(detailEntityList, MasterPlanDetailChangeHisVO.class);
            planChangeHisVO.setMasterPlanDetailList(resultMapList);
        } else {
            planChangeHisVO.setMasterPlanDetailList(BeanMapper.mapList(detailEntityList, MasterPlanDetailChangeHisVO.class));
        }
        return planChangeHisVO;
    }
}

==> zjkj-wzxt-impl-3.0.0-20241017.082338-130-sources.jar: com/ejianc/wzxt/plan/service/impl/MasterPlanChangeHisServiceImpl.java <==
package com.ejianc.wzxt.plan.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.foundation.share.utils.TreeNodeBUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.wzxt.plan.bean.MasterPlanDetailChangeHisEntity;
import com.ejianc.wzxt.plan.enums.ChangeTypeEnum;
import com.ejianc.wzxt.plan.service.IMasterPlanDetailChangeHisService;
import com.ejianc.wzxt.plan.vo.MasterPlanChangeHisVO;
import com.ejianc.wzxt.plan.vo.MasterPlanDetailChangeHisVO;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.wzxt.plan.mapper.MasterPlanChangeHisMapper;
import com.ejianc.wzxt.plan.bean.MasterPlanChangeHisEntity;
import com.ejianc.wzxt.plan.service.IMasterPlanChangeHisService;

import java.util.ArrayList;
import java.util.List;

/**
 * 材料总控计划历史-主表
 * 
 * @author generator
 * 
 */
@Service("masterPlanChangeHisService")
public class MasterPlanChangeHisServiceImpl extends BaseServiceImpl<MasterPlanChangeHisMapper, MasterPlanChangeHisEntity> implements IMasterPlanChangeHisService{


    @Autowired
    private IMasterPlanDetailChangeHisService planDetailChangeHisService;

    @Override
    public MasterPlanChangeHisVO queryDetail(Long id) {
        LambdaQueryWrapper<MasterPlanChangeHisEntity> lambda = Wrappers.<MasterPlanChangeHisEntity>lambdaQuery();
        lambda.eq(MasterPlanChangeHisEntity::getChangePlanId, id);
        MasterPlanChangeHisEntity one = this.getOne(lambda);
        MasterPlanChangeHisVO planChangeHisVO = BeanMapper.map(one, MasterPlanChangeHisVO.class);
        QueryParam queryParam = new QueryParam();
        queryParam.getParams().put("materialMasterPlanId", new Parameter(QueryParam.EQ, one.getId()));
//        queryParam.getOrderMap().put("treeIndex", "asc");
        List<MasterPlanDetailChangeHisEntity> detailEntityListDb = planDetailChangeHisService.queryList(queryParam, false);
        List<MasterPlanDetailChangeHisEntity> detailEntityList = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(detailEntityListDb)) {
            detailEntityListDb.forEach(entity ->{
                if(null == entity.getChangeType() || ChangeTypeEnum.中止项.getCode() != entity.getChangeType()){
                    detailEntityList.add(entity);
                }
            });
        }
        if(CollectionUtils.isNotEmpty(detailEntityList)) {
            for(MasterPlanDetailChangeHisEntity cdEntity : detailEntityList){
                cdEntity.setRowState("add");
            }
            List<MasterPlanDetailChangeHisVO> resultMapList = BeanMapper.mapList(detailEntityList, MasterPlanDetailChangeHisVO.class);
            planChangeHisVO.setMasterPlanDetailList(resultMapList);
        } else {
            planChangeHisVO.setMasterPlanDetailList(BeanMapper.mapList(detailEntityList, MasterPlanDetailChangeHisVO.class));
        }
        return planChangeHisVO;
    }
}
